/*

Copyright 1992 by the University of Edinburgh, Department of Computer Science

Permission to use, copy, modify, distribute, and sell this software and its
documentation for any purpose is hereby granted without fee, provided that
the above copyright notice appear in all copies and that both that
copyright notice and this permission notice appear in supporting
documentation, and that the name of the University of Edinburgh not be used
in advertising or publicity pertaining to distribution of the software
without specific, written prior permission.  The University of Edinburgh
makes no representations about the suitability of this software for any
purpose.  It is provided "as is" without express or implied warranty.

*/
/* dpyvars - print out display parameters in suitable form for setting
   shell variables. (code adapted from xdpyinfo).

   7/3/90 - created (paul).
   26/02/92 GDMR added VISUAL_CLASS and COLORMAP_SIZE
*/

#include <stdio.h>
#include <X11/Xos.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

char *ProgramName;
char hostname[128];

static void usage ()
{
    fprintf (stderr, "usage:  %s [-display displayname]\n",
	     ProgramName);
    exit (1);
}

static char *classes[] = {
	"StaticGray",
	"GrayScale",
	"StaticColor",
	"PseudoColor",
	"TrueColor",
	"DirectColor",
};

main (argc, argv)
    int argc;
    char *argv[];
{
    char *displayname = NULL;
    Display *dpy;
    Visual *vis;
    XVisualInfo vis_template, *vis_return;
    int i, scr, visID;
    double xres, yres;

    ProgramName = argv[0];

    for (i = 1; i < argc; i++) {
	char *arg = argv[i];

	if (arg[0] == '-') {
	    switch (arg[1]) {
	      case 'd':
		if (++i >= argc) usage ();
		displayname = argv[i];
		continue;
	      default:
		usage ();
	    }
	} else
	  usage ();
    }

    dpy = XOpenDisplay (displayname);
    if (!dpy) {
	fprintf (stderr, "%s:  unable to open display \"%s\".\n",
		 ProgramName, XDisplayName (displayname));
	exit (1);
    }

    strcpy(hostname,DisplayString(dpy));
    for (i=0; hostname[i]; ++i) if (hostname[i]==':') hostname[i]=0;
    printf("SERVERHOST=\"%s\"\n", hostname);
    printf("HOST=\"%s\"\n", hostname);
    gethostname(hostname,128);
    printf("CLIENTHOST=\"%s\"\n",hostname);

    printf ("VERSION=\"%d.%d\"\n", ProtocolVersion (dpy), ProtocolRevision (dpy));
    printf ("VENDOR=\"%s\"\n", ServerVendor (dpy));
    printf ("RELEASE=\"%d\"\n", VendorRelease (dpy));

    scr=DefaultScreen(dpy);
    vis = DefaultVisual(dpy, scr);

    xres = ((((double) DisplayWidth(dpy,scr)) * 25.4) /
            ((double) DisplayWidthMM(dpy,scr)));
    yres = ((((double) DisplayHeight(dpy,scr)) * 25.4) /
            ((double) DisplayHeightMM(dpy,scr)));

    printf("HEIGHT=\"%d\"\n",DisplayHeight (dpy, scr));
    printf("WIDTH=\"%d\"\n",DisplayWidth (dpy, scr));
    printf("X_RESOLUTION=\"%d\"\n", (int) (xres + 0.5));
    printf("Y_RESOLUTION=\"%d\"\n", (int) (yres + 0.5));
    printf("PLANES=\"%d\"\n", DisplayPlanes (dpy, scr));

    visID = XVisualIDFromVisual(vis);
    vis_template.visualid = visID;
    vis_return = XGetVisualInfo(dpy, VisualIDMask, &vis_template, &i);
    if (vis_return) {
	printf("VISUAL_CLASS=\"%s\"\n", classes[vis_return->class]);
	printf("COLORMAP_SIZE=\"%d\"\n", vis_return->colormap_size);
    }

    XCloseDisplay (dpy);
    exit (0);
}
